@@ -19,8 +19,12 @@ class Exception_(Exception):
     def __str__(self):
         return self._get_message()
 
+    def get_template(self) -> str:
+        return self.template_
+
     def _get_formatting_attrs(self) -> dict:
         attrs = {}
+
         for key, value in vars(self).items():
             if key not in _NON_FORMATTING_ATTRS:
                 attrs[key] = value
@@ -28,13 +32,14 @@ class Exception_(Exception):
         return attrs
 
     def _get_message(self) -> str:
-        return self._formatter.format(self.template_, **self._get_formatting_attrs())
+        return self._formatter.format(self.get_template(), **self._get_formatting_attrs())
 
     def _check_args_matching(self) -> None:
         try:
             self._get_message()
         except KeyError as error:
             arg = error.args[0]
+
             raise errors.ArgMatchingError(
                 f"argument {arg!r} specified in template was not found among the attributes!",
                 arg=arg
